/*
 * Copyright (C) 2015 Mikel Penagarikano
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package edu.gtts.mediaevalquesst2015;

/**
 *
 * @author Mikel Penagarikano - GTTS
 */
public class Calibration {

		
	public static STDSystem byModelTWV(STDSystem s, double prior){
		double beta = (1.0-prior)/prior;
		STDSystem[] ss = s.split();
		for (STDSystem x : ss) {
			TermWeightedValue twv = x.estimateTWV(beta);
			double offset = -twv.maxValueThreshold();
			for (int i = 0; i < x.score.length; i++) {
				x.score[i] += offset;
				x.decision[i] = (x.score[i] > 0);
			}
		}
		return STDSystem.join(ss);
	}

	public static STDSystem byModelPAV(STDSystem s){
		int nTar = 0;
		for (boolean b : s.isTarget) if (b) nTar++;
		double prior = ((double)nTar) / s.score.length;
		STDSystem[] ss = s.split();
		for (STDSystem x : ss)
			x.score = PoolAdjacentViolators.calibrate(x.score,x.isTarget,null,prior);
		return STDSystem.join(ss);
	}

}
