/*
 * Copyright (C) 2014 Mikel Penagarikano
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package edu.gtts.mediaevalquesst2015;

/**
 *
 * @author mpenagar
 */
public class Cnxe {

	public static double nxe(double[] llr, boolean[] isTar, double prior) {
		double priorEntropy = llr2xe(new double[]{0, 0}, new boolean[]{true, false}, prior);
		double entropy = llr2xe(llr, isTar, prior);
		return entropy / priorEntropy;
	}

	private static double llr2xe(double[] llr, boolean[] isTar, double prior) {
		int nTar = 0;
		for (boolean b : isTar) if (b) nTar++;
		double pTar = prior / nTar;
		double pNon = (1 - prior) / (isTar.length - nTar);
		double logitPrior = Math.log(prior / (1 - prior));
		double xe = 0.0;
		for (int i = 0; i < llr.length; i++) {
			double y = llr[i] + logitPrior;
			double e;
			if (isTar[i]) {
				e = Math.exp(-y);
				xe += pTar * ((1 + e == e) ? -y : Math.log(1 + e));
			} else {
				e = Math.exp(y);
				xe += pNon * ((1 + e == e) ? y : Math.log(1 + e));
			}
		}
		return xe;
	}
	
}
