/*
 * Copyright (C) 2014 Mikel Penagarikano
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package edu.gtts.mediaevalquesst2015;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 *
 * @author mpenagar
 */
public class RTTM {
	
	public static boolean[][] load(String fileName,Map<String,Integer> modelMap,Map<String,Integer> testMap,boolean quiet) throws IOException {
		boolean[][] groundTruth = new boolean[modelMap.size()][testMap.size()];
		int n = 0;
				
		if (!quiet) System.out.print("Loading rttm file: " + fileName + " ... ");
		BufferedReader in = null;
		try {
			in = new BufferedReader(new FileReader(fileName));
			String s,test,model;
			Integer i,j;
			for (int lineNumber = 1; (s = in.readLine()) != null; lineNumber++) {
				String[] sv = s.split(" ");
				if (sv.length != 9) {
					System.err.println("Parse Exception at line " + lineNumber + " while parsing \"" + fileName + "\" :\n\n Wrong number of fields. Found " + sv.length + ", expected 9\n");
					System.exit(1);
				}
				test = sv[1];
				model = sv[5];
				// model & test not contained in  modelMap & testMap are ignored
				if ((i = modelMap.get(model)) == null) continue;
				if ((j = testMap.get(test)) == null) continue;
				if (groundTruth[i][j])
					System.err.println("Parse WARNING at line " + lineNumber + " while parsing \"" + fileName + "\" :\n\n Duplicated entry\n");
				groundTruth[i][j] = true;
				n++;
			}
		} catch (FileNotFoundException ex ) {
			System.err.println("File not found: " + fileName);
			System.exit(1);
		} catch (IOException ex ) {
			Logger.getLogger(Main.class.getName()).log(Level.SEVERE, null, ex);
		} finally {
			if (in != null) in.close();
		}
		if (!quiet) System.out.println(" Done (size: " + n + ")");
		
		return groundTruth;
	}

}
